@@ -1,4 +1,4 @@
-from api import *
+from expressmoney.api import *
 
 __all__ = ('ProfileAPI',)
 
