@@ -2,7 +2,7 @@ from django.core.validators import RegexValidator
 
 from expressmoney.api import *
 
-__all__ = ('UserFileAPI',)
+__all__ = ('UploadFileAPI', 'UserFileAPI',)
 SERVICE_NAME = 'storage'
 
 
@@ -20,3 +20,10 @@ class UserFileAPI(API):
     _service_name = SERVICE_NAME
     _app = 'storage'
     _point = 'user_file'
+
+
+class UploadFileAPI(API):
+    _contract = None
+    _service_name = SERVICE_NAME
+    _app = 'storage'
+    _point = 'upload_file/'
